summaryrefslogtreecommitdiffstats
path: root/khtml/css/parser.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /khtml/css/parser.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/css/parser.cpp')
-rw-r--r--khtml/css/parser.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/css/parser.cpp b/khtml/css/parser.cpp
index c0e6f5869..6cda882ea 100644
--- a/khtml/css/parser.cpp
+++ b/khtml/css/parser.cpp
@@ -210,7 +210,7 @@ using namespace DOM;
//
// The following file defines the function
// const struct props *findProp(const char *word, int len)
//
// with 'props->id' a CSS property in the range from CSS_PROP_MIN to
// (and including) CSS_PROP_TOTAL-1
@@ -224,7 +224,7 @@ using namespace DOM;
int DOM::getPropertyID(const char *tagStr, int len)
{
- const struct props *propsPtr = findProp(tagStr, len);
+ const struct props *propsPtr = tqfindProp(tagStr, len);
if (!propsPtr)
return 0;
@@ -233,7 +233,7 @@ int DOM::getPropertyID(const char *tagStr, int len)
static inline int getValueID(const char *tagStr, int len)
{
- const struct css_value *val = findValue(tagStr, len);
+ const struct css_value *val = tqfindValue(tagStr, len);
if (!val)
return 0;
@@ -210,7 +210,7 @@ using namespace DOM;
//
// The following file defines the function
-// const struct props *findProp(const char *word, int len)
+// const struct props *tqfindProp(const char *word, int len)
//
// with 'props->id' a CSS property in the range from CSS_PROP_MIN to